@@ -7,22 +7,11 @@ use serde::{Deserialize, Serialize};
 use serde_with::skip_serializing_none;
 
 pub use cluster::ClusterIpFamily;
+pub use cluster::ClusterPhase;
 pub use cluster::InvalidIpFamily;
 pub use cluster::*;
-pub use common::*;
-pub use condition::*;
-pub use phase::ClusterPhase;
 
 use crate::errors as capierrors;
 
-mod cluster;
-mod common;
-mod condition;
-mod phase;
-
-// #[derive(Clone, Debug, Serialize, Deserialize, Default)]
-// pub struct Cluster {
-//     pub metadata: metav1::ObjectMeta,
-//     pub spec: Option<ClusterSpec>,
-//     pub status: Option<ClusterStatus>,
-// }
+pub mod cluster;
+pub mod infrastructure;
